@@ -6,6 +6,7 @@ that are 3 letters or fewer. Thus, the standard metasyntactic variables in
 these tests have been amended to 'fooo' and 'baar'. Ho hum.
 """
 
+import os
 from unittest import skipUnless
 
 from django.db import models
@@ -514,6 +515,10 @@ class AdminIntegrationTest(SearchTestBase):
     urls = "watson.tests"
     
     def setUp(self):
+        self.old_TEMPLATE_DIRS = settings.TEMPLATE_DIRS
+        settings.TEMPLATE_DIRS = (
+            os.path.join(os.path.dirname(admin.__file__), "templates"),
+        )
         super(AdminIntegrationTest, self).setUp()
         self.user = User(
             username = "foo",
@@ -525,7 +530,18 @@ class AdminIntegrationTest(SearchTestBase):
     
     @skipUnless("django.contrib.admin" in settings.INSTALLED_APPS, "Django admin site not installed")
     def testAdminIntegration(self):
-        self.client.login(username="foo", password="bar")
+        # Log the user in.
+        if hasattr(self, "settings"):
+            with self.settings(INSTALLED_APPS=tuple(set(tuple(settings.INSTALLED_APPS) + ("django.contrib.sessions",)))):  # HACK: Without this the client won't log in, for some reason.
+                self.client.login(
+                    username = "foo",
+                    password = "bar",
+                )
+        else:
+            self.client.login(
+                username = "foo",
+                password = "bar",
+            )
         # Test a search with no query.
         response = self.client.get("/admin/auth/watsontestmodel1/")
         self.assertContains(response, "instance11")
@@ -544,12 +560,20 @@ class AdminIntegrationTest(SearchTestBase):
         super(AdminIntegrationTest, self).tearDown()
         self.user.delete()
         del self.user
+        settings.TEMPLATE_DIRS = self.old_TEMPLATE_DIRS
         
         
 class SiteSearchTest(SearchTestBase):
 
     urls = "watson.tests"
     
+    def setUp(self):
+        self.old_TEMPLATE_DIRS = settings.TEMPLATE_DIRS
+        settings.TEMPLATE_DIRS = (
+            os.path.join(os.path.dirname(admin.__file__), "templates"),
+        )
+        super(SiteSearchTest, self).setUp()
+    
     def testSiteSearch(self):
         # Test a search than should find everything.
         response = self.client.get("/simple/?q=title")
@@ -626,5 +650,8 @@ class SiteSearchTest(SearchTestBase):
         self.assertTrue("title model2 instance22" in results)
         # Test a search with an invalid page.
         response = self.client.get("/custom/json/?fooo=title&page=200")
-        results = set(result["title"] for result in json.loads(response.content)["results"])
-        self.assertEqual(len(results), 0)
\ No newline at end of file
+        self.assertEqual(response.status_code, 404)
+        
+    def tearDown(self):
+        super(SiteSearchTest, self).tearDown()
+        settings.TEMPLATE_DIRS = self.old_TEMPLATE_DIRS
\ No newline at end of file
